{ config
, pkgs
, inputs
, ...
}: {
  programs.mpv = {
    enable = true;
    package = pkgs.mpv;
  };
  programs.thunderbird = {
    enable = true;
    package = pkgs.thunderbird-128;
    profiles."main" = {
      isDefault = true;
    };
  };
  programs.nheko = {
    # enable = true; # insecure due to downstream olm
  };
  programs.obs-studio = {
    enable = true;
    plugins = with pkgs.obs-studio-plugins; [
      wlrobs
      obs-backgroundremoval
      obs-pipewire-audio-capture
      obs-vaapi
      obs-gstreamer
    ];
  };

  xdg.desktopEntries = {
    steam-15 = {
      name = "Steam (1.5 Scaling)";
      type = "Application";
      icon = "steam";
      comment = "steam with forced 2x scaling for highdpi displays";
      exec = "steam -forcedesktopscaling 1.5";
      terminal = false;
      prefersNonDefaultGPU = true;
      categories = [ "Network" "FileTransfer" "Game" ];
    };

    steam-2 = {
      name = "Steam (2.0 Scaling)";
      type = "Application";
      icon = "steam";
      comment = "steam with forced 2x scaling for highdpi displays";
      exec = "steam -forcedesktopscaling 2";
      terminal = false;
      prefersNonDefaultGPU = true;
      categories = [ "Network" "FileTransfer" "Game" ];
    };
  };

  home = {
    file."Pictures/default_background.png".source = config.stylix.image;

    packages = with pkgs; [
      bitwarden
      airshipper
      ardour
      brave
      cavalier
      ffmpeg
      freetube
      filelight
      element-desktop
      inkscape
      jellyfin-mpv-shim
      warp-terminal
      libsForQt5.kasts
      krita
      kdePackages.kate
      kdePackages.kdenlive
      kdePackages.kleopatra
      kdePackages.plasma-vault
      kdePackages.plasma-browser-integration
      kdePackages.kio-admin
      nextcloud-client
      onlyoffice-bin
      protonup-qt
      signal-desktop
      webcord-vencord
      tome4
      shattered-pixel-dungeon
      gst_all_1.gst-vaapi
      waypipe
      veracrypt
      lutris
      heroic
      kdePackages.konversation
      unar
      fuse
      qbittorrent
      pcsx2
      xdelta
      winetricks
      # blender
      # miraclecast
      # rustdesk
      # deadbeef-with-plugins
      # flightgear
      # orbiter
    ];
  };
}
